==> ebt_tabs-1.3.0.tar.gz: ebt_tabs/js/jquery_ui_tabs/jquery_ui_tabs.js <==
(function ($, Drupal) {

  /**
   * EBT Tabs behavior.
   */
  Drupal.behaviors.ebtTabs = {
    attach: function (context, settings) {
      $.each(drupalSettings.ebtTabs, function(i, value){
        // Initialize jQuery UI tabs.
        var blockClass = drupalSettings.ebtTabs[i].blockClass;
        if ($('.' + blockClass).length == 0) {
          return;
        }
        var $blockTabs = $('.' + blockClass);
        if ($blockTabs.hasClass('tabs-added')) {
          return;
        }
        $blockTabs.append('<div id="ebt-tabs-' + blockClass + '"></div>');
        $('#ebt-tabs-' + blockClass).prepend('<ul class="tabs-' + blockClass + '"></ul>');
        $blockTabs.find('.field--name-field-ebt-tabs > .field__item').once('reorder-blocks').each(function(index) {
          $(this)
            .find('.ebt-tab-title')
            .appendTo($('.tabs-' + blockClass))
            .wrap('<li><a href="#ebt-tabs-' + blockClass + '-' + index + '"></a></li>');
          $(this)
            .find('.ebt-tab-content')
            .appendTo($('#ebt-tabs-' + blockClass))
            .wrap('<div id="ebt-tabs-' + blockClass + '-' + index + '"></div>');
        });

        var options = {};
        drupalBlockSettings = drupalSettings.ebtTabs[i].options;
        if (drupalBlockSettings.active != undefined && drupalBlockSettings.active != '') {
          options['active'] = parseInt(drupalBlockSettings.active);
        }

        if (drupalBlockSettings.collapsible != undefined) {
          if (drupalBlockSettings.collapsible == 1) {
            options['collapsible'] = true;
          }
          else {
            options['collapsible'] = false;
          }
        }

        if (drupalBlockSettings.closed != undefined && drupalBlockSettings.closed == 1) {
          options['active'] = false;
        }

        if (drupalBlockSettings.disable != undefined) {
          if (drupalBlockSettings.disable == 1) {
            options['disable'] = true;
          }
          else {
            options['disable'] = false;
          }
        }

        if (drupalBlockSettings.heightStyle != undefined) {
          options['heightStyle'] = drupalBlockSettings.heightStyle;
        }

        $('#ebt-tabs-' + blockClass).tabs(options);
        $blockTabs.addClass('tabs-added');
      });
    }
  };

})(jQuery, Drupal);

==> ebt_tabs-1.4.1.tar.gz: ebt_tabs/js/jquery_ui_tabs/jquery_ui_tabs.js <==
(function ($, Drupal) {

  /**
   * EBT Tabs behavior.
   */
  Drupal.behaviors.ebtTabs = {
    attach: function (context, settings) {
      $.each(drupalSettings.ebtTabs, function(i, value){
        // Initialize jQuery UI tabs.
        var blockClass = drupalSettings.ebtTabs[i].blockClass;
        if ($('.' + blockClass).length == 0) {
          return;
        }
        var $blockTabs = $('.' + blockClass);
        if ($blockTabs.hasClass('tabs-added')) {
          return;
        }
        $blockTabs.append('<div id="ebt-tabs-' + blockClass + '"></div>');
        $('#ebt-tabs-' + blockClass).prepend('<ul class="tabs-' + blockClass + '"></ul>');

        let tabElement = '.' + blockClass + ' .field--name-field-ebt-tabs .paragraph--type--ebt-tab';
        const $elements =  $(once('reorderBlocks', tabElement, context));

        $elements.each(function(index) {
          $(this)
            .find('.ebt-tab-title')
            .appendTo($('.tabs-' + blockClass))
            .wrap('<li><a href="#ebt-tabs-' + blockClass + '-' + index + '"></a></li>');
          $(this)
            .find('.ebt-tab-content')
            .appendTo($('#ebt-tabs-' + blockClass))
            .wrap('<div id="ebt-tabs-' + blockClass + '-' + index + '"></div>');
        });

        var options = {};
        drupalBlockSettings = drupalSettings.ebtTabs[i].options;
        if (drupalBlockSettings.active != undefined && drupalBlockSettings.active != '') {
          options['active'] = parseInt(drupalBlockSettings.active);
        }

        if (drupalBlockSettings.collapsible != undefined) {
          if (drupalBlockSettings.collapsible == 1) {
            options['collapsible'] = true;
          }
          else {
            options['collapsible'] = false;
          }
        }

        if (drupalBlockSettings.closed != undefined && drupalBlockSettings.closed == 1) {
          options['active'] = false;
        }

        if (drupalBlockSettings.disable != undefined) {
          if (drupalBlockSettings.disable == 1) {
            options['disable'] = true;
          }
          else {
            options['disable'] = false;
          }
        }

        if (drupalBlockSettings.heightStyle != undefined) {
          options['heightStyle'] = Drupal.checkPlain(drupalBlockSettings.heightStyle);
        }

        $('#ebt-tabs-' + blockClass).tabs(options);
        $blockTabs.addClass('tabs-added');
      });
    }
  };

})(jQuery, Drupal);
